@@ -2,7 +2,7 @@
 # Copyright (c) Twisted Matrix Laboratories.
 # See LICENSE for details.
 
-from __future__ import division, absolute_import
+from __future__ import division, absolute_import, print_function
 
 import os, sys, errno, warnings
 try:
@@ -14,8 +14,6 @@ try:
 except ImportError:
     setgroups = getgroups = None
 
-from twisted.python.deprecate import deprecated
-from twisted.python.versions import Version
 from twisted.python.compat import _PY3, unicode
 if _PY3:
     UserDict = object
@@ -70,7 +68,7 @@ class InsensitiveDict:
         k = self._lowerOrReturn(key)
         return k in self.data
 
-    __contains__=has_key
+    __contains__ = has_key
 
     def _doPreserve(self, key):
         if not self.preserve and (isinstance(key, bytes)
@@ -164,6 +162,7 @@ class OrderedDict(UserDict):
                     self[k] = v
         if len(kwargs):
             self.update(kwargs)
+
     def __repr__(self):
         return '{'+', '.join([('%r: %r' % item) for item in self.items()])+'}'
 
@@ -215,6 +214,14 @@ class OrderedDict(UserDict):
         for k, v in d.items():
             self[k] = v
 
+
+if _PY3:
+    # Python 3 has its own OrderedDict that we should use instead.
+    del OrderedDict
+    from collections import OrderedDict
+
+
+
 def uniquify(lst):
     """Make the elements of a list unique by inserting them into a dictionary.
     This must not change the order of the input lst.
@@ -476,7 +483,7 @@ def raises(exception, f, *args, **kwargs):
     return 0
 
 
-class IntervalDifferential:
+class IntervalDifferential(object):
     """
     Given a list of intervals, generate the amount of time to sleep between
     "instants".
@@ -511,14 +518,14 @@ class IntervalDifferential:
         return _IntervalDifferentialIterator(self.intervals, self.default)
 
 
-class _IntervalDifferentialIterator:
+class _IntervalDifferentialIterator(object):
     def __init__(self, i, d):
 
         self.intervals = [[e, e, n] for (e, n) in zip(i, range(len(i)))]
         self.default = d
         self.last = 0
 
-    def next(self):
+    def __next__(self):
         if not self.intervals:
             return (self.default, None)
         last, index = self.intervals[0][0], self.intervals[0][2]
@@ -528,6 +535,9 @@ class _IntervalDifferentialIterator:
         self.last = last
         return result, index
 
+    # Iterators on Python 2 use next(), not __next__()
+    next = __next__
+
     def addInterval(self, i):
         if self.intervals:
             delay = self.intervals[0][0] - self.intervals[0][1]
@@ -837,48 +847,6 @@ def untilConcludes(f, *a, **kw):
 
 
 
-_idFunction = id
-
-@deprecated(Version("Twisted", 13, 0, 0))
-def setIDFunction(idFunction):
-    """
-    Change the function used by L{unsignedID} to determine the integer id value
-    of an object.  This is largely useful for testing to give L{unsignedID}
-    deterministic, easily-controlled behavior.
-
-    @param idFunction: A function with the signature of L{id}.
-    @return: The previous function being used by L{unsignedID}.
-    """
-    global _idFunction
-    oldIDFunction = _idFunction
-    _idFunction = idFunction
-    return oldIDFunction
-
-
-# A value about twice as large as any Python int, to which negative values
-# from id() will be added, moving them into a range which should begin just
-# above where positive values from id() leave off.
-_HUGEINT = (sys.maxsize + 1) * 2
-
-@deprecated(Version("Twisted", 13, 0, 0), "builtin id")
-def unsignedID(obj):
-    """
-    Return the id of an object as an unsigned number so that its hex
-    representation makes sense.
-
-    This is mostly necessary in Python 2.4 which implements L{id} to sometimes
-    return a negative value.  Python 2.3 shares this behavior, but also
-    implements hex and the %x format specifier to represent negative values as
-    though they were positive ones, obscuring the behavior of L{id}.  Python
-    2.5's implementation of L{id} always returns positive values.
-    """
-    rval = _idFunction(obj)
-    if rval < 0:
-        rval += _HUGEINT
-    return rval
-
-
-
 def mergeFunctionMetadata(f, g):
     """
     Overwrite C{g}'s name and docstring with values from C{f}.  Update
@@ -1071,19 +1039,17 @@ __all__ = [
     "getPassword", "println", "makeStatBar", "OrderedDict",
     "InsensitiveDict", "spewer", "searchupwards", "LineLog",
     "raises", "IntervalDifferential", "FancyStrMixin", "FancyEqMixin",
-    "switchUID", "SubclassableCStringIO", "unsignedID", "mergeFunctionMetadata",
+    "switchUID", "SubclassableCStringIO", "mergeFunctionMetadata",
     "nameToLabel", "uidFromString", "gidFromString", "runAsEffectiveUser",
-    "untilConcludes",
-    "runWithWarningsSuppressed",
-    ]
+    "untilConcludes", "runWithWarningsSuppressed",
+]
 
 
 if _PY3:
-    __all3__ = ["FancyEqMixin", "setIDFunction", "unsignedID", "untilConcludes",
-                "runWithWarningsSuppressed", "FancyStrMixin", "nameToLabel",
-                "InsensitiveDict"]
+    __notported__ = ["SubclassableCStringIO", "LineLog", "spewer",
+                     "makeStatBar"]
     for name in __all__[:]:
-        if name not in __all3__:
+        if name in __notported__:
             __all__.remove(name)
             del globals()[name]
-    del name, __all3__
+    del name, __notported__
